---
comments: true
icon: material/folder-open
---

# Projects

Here are some examples of projects developed with `maliang`.

!!! tip "Tips"

    If you want to add your projects written in tkt to the site, no problem! As long as the following requirements are met, I will consider adding your project here!

    - [X] Add `maliang` to *requirements.txt* and indicate which version you are using so I can find your project;
    - [X] Show a preview of your own project in README so I can show your project here;

    By the way, if your project provides a preview of the light and dark themes, there will also be a preview of the two themes, so you can see the preview of the different themes by switching the theme of this website.
